==> ksystemlog-18.07.80.tar.xz: ksystemlog-18.07.80/src/modes/apache/apacheLogMode.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _APACHE_LOG_MODE_H_
#define _APACHE_LOG_MODE_H_

/**
 * Apache Log Mode Identifier
 */
#define APACHE_LOG_MODE_ID "apacheLogMode"

/**
 * Apache Log Icon
 */
#define APACHE_MODE_ICON "network-server"

#include <QList>

#include "logFile.h"

#include "logMode.h"

class ApacheConfiguration;
class ApacheConfigurationWidget;

class ApacheLogMode : public LogMode
{
    Q_OBJECT

public:
    explicit ApacheLogMode(QSharedPointer<ApacheConfiguration> &apacheConfiguration,
                           ApacheConfigurationWidget *apacheConfigurationWidget);

    ~ApacheLogMode();

    Analyzer *createAnalyzer(const QVariant &options = QVariant()) Q_DECL_OVERRIDE;

    QList<LogFile> createLogFiles() Q_DECL_OVERRIDE;
};

#endif // _APACHE_LOG_MODE_H_

==> ksystemlog-19.12.2.tar.xz: ksystemlog-19.12.2/src/modes/apache/apacheLogMode.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef APACHE_LOG_MODE_H
#define APACHE_LOG_MODE_H

/**
 * Apache Log Mode Identifier
 */
#define APACHE_LOG_MODE_ID "apacheLogMode"

/**
 * Apache Log Icon
 */
#define APACHE_MODE_ICON "preferences-system-network"

#include <QList>

#include "logFile.h"

#include "logMode.h"

class ApacheConfiguration;
class ApacheConfigurationWidget;

class ApacheLogMode : public LogMode
{
    Q_OBJECT

public:
    explicit ApacheLogMode(QSharedPointer<ApacheConfiguration> &apacheConfiguration,
                           ApacheConfigurationWidget *apacheConfigurationWidget);

    ~ApacheLogMode() override;

    Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;

    QList<LogFile> createLogFiles() override;
};

#endif // _APACHE_LOG_MODE_H
